<?php
/**
 * @package   AkeebaTicketSystem
 * @copyright Copyright (c)2011-2017 Nicholas K. Dionysopoulos
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\TicketSystem\Admin\Controller;

use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Admin\Model\JoomlaUsers;
use Akeeba\TicketSystem\Admin\Model\Tickets;
use Akeeba\TicketSystem\Admin\Model\UserTags;
use FOF30\Controller\DataController;

defined('_JEXEC') or die;

trait TraitSaveUserTags
{
	/**
	 * Handles user tags saving
	 *
	 * User tags are normally saved when a manager submits a Post (reply). However, if a ticket is filed by a manager
	 * then we will save user tags anyway.
	 *
	 * @return  void
	 */
	protected function saveUserTags()
	{
		// Am I a manager?
		/** @var DataController $this*/
		/** @var Tickets $model */
		$model     = $this->getModel();
		$category  = $model->catid;
		$isManager = Permissions::isManager($category);

		// If it's not a manager they're not allowed to save user tags
		if (!$isManager)
		{
			return;
		}

		// Get and save user tags
		$tags = $this->input->get('usertags', array(), 'array', 2);

		// Since we have different names for the model regarding Joomla users, we have to do this trick..
		if ($this->container->platform->isBackend())
		{
			$modelName = 'JoomlaUsers';
		}
		else
		{
			$modelName = 'Jusers';
		}

		/** @var JoomlaUsers $juserModel */
		$juserModel = $this->container->factory->model($modelName)->tmpInstance();
		$juserModel->find($model->created_by);

		// First of all let's remove any tag
		/** @var UserTags $atstag */
		foreach($juserModel->atstags as $atstag)
		{
			$juserModel->atstags->removeById($atstag->getId());
		}

		// Then let's push the new ones
		/** @var UserTags $usertags */
		$usertags = $this->container->factory->model('UserTags')->tmpInstance();

		$newTags = $usertags->where($usertags->getIdFieldName(), 'in', $tags)->get();

		foreach($newTags as $newTag)
		{
			$juserModel->atstags->add($newTag);
		}

		$juserModel->getRelations()->save('atstags');

		// Finally, nuke any tags that are still stored in the user table (we will remove this code in later versions)
		$db   = \JFactory::getDbo();
		$user = \JFactory::getUser($model->created_by);
		$params = $user->params;

		// The docblock says it should be an object, but in reality it's a string.
		if (!is_object($params))
		{
			$params = new \JRegistry($params);
		}

		// Run only if we really have to delete old tags
		if ($params->get('ats_tags'))
		{
			$params->set('ats_tags', null);

			$query = $db->getQuery(true)
				->update($db->qn('#__users'))
				->where($db->qn('id').' = '.$db->q($model->created_by))
				->set($db->qn('params').' = '.$db->q($params->toString()));

			$db->setQuery($query)->execute();
		}
	}
}